@@ -15,12 +15,11 @@
 #'
 #' @export
 arrange <- function(.data, ...) {
-  check_is_dataframe(.data)
   UseMethod("arrange")
 }
 
 #' @export
-arrange.default <- function(.data, ...) {
+arrange.data.frame <- function(.data, ...) {
   context$setup(.data)
   on.exit(context$clean(), add = TRUE)
   rows <- eval(substitute(order(...)), envir = context$.data)
