@@ -24,8 +24,12 @@
 #'
 #' @export
 rename <- function(.data, ...) {
-  check_is_dataframe(.data)
-  new_names <- names(deparse_dots(...))
+  UseMethod("rename")
+}
+
+#' @export
+rename.data.frame <- function(.data, ...) {
+  new_names <- names(dotdotdot(...))
   if (length(new_names) == 0L) {
     warning("You didn't give any new names")
     return(.data)
@@ -52,6 +56,11 @@ rename <- function(.data, ...) {
 #' @rdname rename
 #' @export
 rename_with <- function(.data, .fn, .cols = everything(), ...) {
+  UseMethod("rename_with")
+}
+
+#' @export
+rename_with.data.frame <- function(.data, .fn, .cols = everything(), ...) {
   if (!is.function(.fn)) stop("`", .fn, "` is not a valid function")
   grouped <- inherits(.data, "grouped_data")
   if (grouped) grp_pos <- which(colnames(.data) %in% group_vars(.data))
@@ -62,6 +71,6 @@ rename_with <- function(.data, .fn, .cols = everything(), ...) {
     stop("New names must be unique however `", deparse(substitute(.fn)), "` returns duplicate column names")
   }
   colnames(.data)[col_pos] <- new_cols
-  if (grouped) .data <- set_groups(.data, colnames(.data)[grp_pos])
+  if (grouped) .data <- groups_set(.data, colnames(.data)[grp_pos])
   .data
 }
