@@ -22,6 +22,12 @@ expect_equal(
   info = "Test multiple summarise with column names"
 )
 
+expect_equal(
+  summarise(data.frame(x = 1:10), y = mean(x), z = y + 1),
+  data.frame(y = 5.5, z = 6.5),
+  info = "Can use freshly create variables"
+)
+
 expect_equal(
   mtcars %>% summarise(n(), range(mpg)),
   structure(list(`n()` = c(32L, 32L), `range(mpg)` = c(10.4, 33.9)), class = "data.frame", row.names = c(NA, -2L)),
@@ -70,3 +76,25 @@ expect_equal(
   ),
   info = "Test multiple groups and multiple summary functions"
 )
+
+expect_equal(
+  summarise(mtcars),
+  data.frame(),
+  info = "empty summarise returns empty data.frame"
+)
+
+res <- mtcars %>% group_by(am) %>% summarise()
+expect_equal(
+  class(res),
+  c("grouped_data", "data.frame"),
+  info = "empty grouped summarise() returns groups #1"
+)
+expect_equal(
+  {
+    attr(res, "groups") <- NULL
+    class(res) <- "data.frame"
+    res
+  },
+  data.frame(am = c(0, 1)),
+  info = "empty grouped summarise() returns groups #2"
+)
